#
# spec file for package hub
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define ver %{version}
Name:           hub
Version:        2.14.2
Release:        lp152.1.24
Summary:        Command-line wrapper for git and GitHub
License:        MIT
Group:          Development/Tools/Version Control
URL:            https://github.com/github/hub
Source:         https://github.com/github/%{name}/archive/v%{ver}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fish
BuildRequires:  go
BuildRequires:  groff
BuildRequires:  vim
BuildRequires:  zsh
Provides:       rubygem-hub = %{version}
Obsoletes:      rubygem-hub < 2.0

%description
hub is a command line tool that wraps git in order to extend it with
extra features and commands that make working with GitHub easier.

%prep
%setup -q -n %{name}-%{ver}
sed -i -e 's#bin/ronn --#ronn --#' -e 's#script/bootstrap#true#' Makefile
chmod +x script/install.sh
sed -i -e 's#cd .*#true#' script/install.sh

%build
export LANG=en_US.UTF-8
export GOPATH=$PWD
mkdir -p $GOPATH/src/github.com/github/
# Copy the vendor directory into the GOPATH
cp -r $PWD/vendor/* $GOPATH/src
ln -s $PWD $GOPATH/src/github.com/github/hub
make %{?_smp_mflags} bin/hub man-pages

%install
prefix=%{buildroot}%{_prefix} script/install.sh
install -Dpm 0644 etc/hub.bash_completion.sh \
  %{buildroot}%{_datadir}/bash-completion/completions/hub
install -Dpm 0644 etc/hub.fish_completion \
  %{buildroot}%{_datadir}/fish/vendor_completions.d/hub.fish
install -Dpm 0644 etc/hub.zsh_completion \
  %{buildroot}%{_datadir}/zsh/site-functions/_hub
# Install vim-related files to a vim runtimepath that is set per default on openSUSE
install -d %{buildroot}%{_datadir}/vim/site
mv %{buildroot}%{_datadir}/vim/vimfiles/* %{buildroot}%{_datadir}/vim/site

rm -rf %{buildroot}%{_datadir}/doc/hub-doc/

%check
#make test
#make test-all

%files
%doc README.md
%license LICENSE
%{_bindir}/hub
%{_mandir}/man1/hub.1%{?ext_man}
%{_mandir}/man1/hub-*.1%{?ext_man}
%{_datadir}/bash-completion/completions/hub
%{_datadir}/fish/vendor_completions.d/hub.fish
%{_datadir}/zsh/site-functions/_hub
%{_datadir}/vim/site/ftdetect/pullrequest.vim
%{_datadir}/vim/site/syntax/pullrequest.vim

%changelog
* Fri Mar  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.14.2
  * Ensure man pages are shown at full width
  * Fix subject in ci-status docs
  * Indicate in docs that you can do plain git push after hub pr
    checkout
  * Fix using hub inside git worktree
* Wed Jan 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.14.1
  Features:
  * New command: hub issue update
  * New command: hub issue transfer
  * Support git flag hub version --build-options
  * Refuse to follow HTTP 301/302 redirects for non-GET requests
  Fixes:
  * Ensure that grep command is being used in shell completions
  * Consult global git config color.ui setting when --color=auto
  Improvements:
  * Print more user-friendly HTTP 40x errors
  * Enable debugging file uploads via HUB_VERBOSE=1 hub release
    create -a <file>
  * Improve parsing malformed YAML config files
- Update to version 2.13.0
  * New command: hub gist
  * Add git pr show --format=... flag
  * Add hub api --obey-ratelimit flag
  * hub help: support compressed man pages
  * Add hub release download --include=PATTERN flag
  * hub help: Enable hub help --web <command>
  * hub release: Retry attaching release assets on 5xx server
    errors
  * hub pr checkout fixes
    + handle case when the PR given matches the current branch
    + avoid overriding existing branch merge config
  * hub release: Fail fast when attempting to attach unavailable
    files
  * Honor HTTPS_PROXY, NO_PROXY environment variables
  * Strip "co-authored-by" lines when populating PR body from git
    log
  * git compatibility: have hub <cmd> --help open the man page
  * hub fork bash completion improvements
  * hub pr fish completion improvements
* Sat Oct  5 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.12.8
  * hub compare: improve upstream branch detection & error messages
  * hub compare: allow slash character in branch names
  * hub api: fix GraphQL requests made to Enterprise hosts
  * Docs: clarify --message, --file, and --edit flags
* Sat Sep 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.12.6
  * Added hub pr to fish completions script
  * Have fish completions script wrap git if hub is aliased
* Sun Sep  8 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.12.4
  Bug fixes:
  * Fix invocation of hub --paginate
  * Consistently expand all occurrences of {owner} and {repo} in
    hub api
  * Docs: unlist %%NC/%%Nc among available fields in
    hub pr list --format
  Enhancements:
  * GitHub Actions compatibility: infer GITHUB_USER value from
    GITHUB_REPOSITORY if available
  * Handle TERM signal during password prompt in terminal
  * Use consistent quote style in hub sync output
- Update to version 2.12.3
  * Allow hub use within GitHub Actions by specifying GITHUB_USER
  * Show friendlier error message when GITHUB_TOKEN is set, but
    fetching the current user fails
* Fri Jul 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.12.2
  * Improve pull-request push target detection for git config
    push.default is "upstream", but when the current branch does
    not have upstream configuration
- Update to version 2.12.1
  Fixes:
  * hub pull-request: Avoid crash when the current branch is pushed
    to a non-GitHub remote BROWSER environment variable now supports
    values with spaces in them (must be shell-quoted)
  * hub help: support man appearing in a path that has spaces
  * Docs: mention that comma-separated lists must not have spaces
- Update to version 2.12.0
  * Add hub api --paginate option to automatically fetch all pages
    of results
  * Add hub pr show [<number>] command to open a pull request in
    the browser
  * Add hub pull-request --no-maintainer-edits flag to disallow
    project maintainers being able to push to your branch
  * Abort hub pull-request with a helpful error message if the
    current branch wasn't pushed to a git remote hub issue -M now
    accepts milestone names instead of just numbers
  * Drop support for legacy hub.http-clone git config value (this
    was broken for a while and nobody complained, so I deemed it
    safe to drop in a minor rather than a major release)
  Fixes
  * Fix querying git configuration when GIT_TRACE is used
  * Support detached HEAD if hub pull-request --head was passed
  * Fix newline in hub create error message
  * Ensure HTTP connection reuse across API calls
* Sat Mar 30 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.11.1
  * Fix non-draft pull requests for certain repositories
- Update to version 2.11.0
  * Create draft pull requests with hub pull-request --draft
    Draft pull requests are considered work in progress: they don't
    automatically request others for review and they are not
    mergeable while in their draft state.
* Wed Mar 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.10.1
  Bugfix release:
  * Allow repository names that start with a dash character
  * Fix writing over existing cache files
* Tue Mar  5 2019 Martin Hauke <mardnh@gmx.de>
- Run spec-cleaner
- Set proper GOPATH during the build
- Drop not longer required 'rubygem(ronn)' from the BuildRequires
- Package VIM-plugins
- Update to version 2.10.0
  Features
  * New hub pr list --format fields %%pS and %%pC for PR state and color
  * Have commands with rich output respect the --color flag
  Fixes
  * Make man pages parseable with whatis
  * Make hub checkout work independently of remote refspec
- Update to version 2.9.0
  Features
  * Add support for hub ci-status --format <FORMAT> string
  * Add hub create --remote-name <REMOTE> flag
  * Allow passing in a raw request body via hub api --input <FILE>
  * Cache HTTP 4xx (except 403) server responses in hub api --cache
  Fixes
  * Ensure consistent ordering of hub ci-status -v results
  * Avoid crashing on invalid GitHub hostname
  * Fix parsing empty string within command-line arguments
- Update to version 2.8.4
  * Add hub api -H flag to set HTTP request headers
  * Add hub api -i flag to output HTTP response headers
  * Change how hub api deals with HTTP errors:
    + HTTP response is now printed on stdout regardless of HTTP status
    + No longer print an extra newline after HTTP response body
    + No more Error: HTTP {STATUS} message on stderr
    + hub exits with status 22 instead of 1
  * Fix hub execution under WSL (Windows Subsystem for Linux)
- Update to version 2.8.3
  * New hub api command for scripting with GitHub API
  * Re-implement CLI flag parsing so that --message <MSG> is
    equivalent to --message=<MSG>
  * Re-implement make man-pages in Go instead of Ruby
  * issue create --label is now issue create --labels to align
    with existing documentation
  * Output crash debugging information on stderr instead of stdout
  * Fix uploading assets with hub release
- Update to version 2.7.1
  * Respect chosen Enterprise host on hub init -g
  * Ensure consistent order of options when prompted to choose
    between multiple configured GitHub hosts
  * Ensure alphabetical sort of hub issue labels output
  * Improve contrast of label text vs. its background color
  * Various documentation formatting tweaks
- Update to version 2.7.0
  Features
  * Add support for hub pr list --state=merged
  * Add base/head/merge commit SHA and merged date information to
    hub pr list --format=FORMAT
  * Un-deprecate converting issues to pull requests with hub
    pull-request -i <issue>
- Update to version 2.6.1
  * Fix using git aliases for git 2.20
  * Add support for passing multiple --message options for compatibility
    with git
  * Allow the %%h token in HostName value read from ssh config
- Update to version 2.6.0
  Features
  * Use "scissors" line to delineate comments in editable messages instead
    of stripping away lines that start with #. This helps preserve Markdown
    headings in hub pull-request, hub release create, and similar commands
    that open a text editor interactively.
  * New command hub issue show <NUMBER>
  * Add hub release show --format=<FORMAT> functionality
  * hub pr list --format=%%rs lists requested reviewers
  * Add support for communicating with GitHub Enterprise over Unix socket
  Fixes
  * Prevent hub create setting a public upstream when creating a
    private repo
  * Fix hub create in place of a renamed repo
  * Fix hub release create/edit/delete when there are multiple git remotes
  * Auto-detect private/pushable repos in hub remote add
  * Fix hub ci-status exit code when there is only Checks
  * Allow hub compare <RANGE> even if not on any branch
  * Ensure consistent sort direction when listing issues, PRs
  * Match requested team names by slug instead of name in
    hub pull-request -r <TEAM>
- Update to version 2.5.1
  * hub issue create: ignore the .github/ISSUE_TEMPLATE directory
    instead of crashing
  * hub pull-request: avoid re-requesting reviewers in case of CODEOWNERS
  * hub ci-status: handle cases when Checks API is unavailable, like
    older GitHub Enterprise
  * Handle HTTP 422 message format from server response
  * Ignore crash for malformed ~/.config/hub file
  * Clarify hub init -g documentation that it doesn't imply hub create
  * hub clone: add more documentation about git protocol used
- Update to version 2.5.0
  Features
  * Have ci-status also query Checks API
  Fixes
  * Do not pass `--cmd' to vi editor to ensure compatibility with
    older vi
  * Simplify cherry-picking commits from pull request URLs
  * Allow single-character branches/tag names in hub compare
  * Fix hub compare for Enterprise when <USER> is specified
  * Support remote add -t BRANCH argument
  * Bash shell completion fixes for git 2.18
  * Documentation fixes
- Update to version 2.4.0
  Features
  * hub delete [<OWNER>/]<REPO>
  * Add hub compare --copy flag
  * Add hub release --format=<FORMAT> option
  * Add hub pull-request --no-edit flag
  * When checking out a pull request, ensure that git pushwith no
    arguments works
  * Support XDG Base Directory Specification
  Tweaks
  * Enable hub pr list -h <BRANCH> when owner isn't specified
  * Include docs/ in list of locations to look up pull request and issue
    templates in
* Thu Jun 21 2018 mpluskal@suse.com
- Modernise spec file a bit
* Thu Jun 21 2018 bwiedemann@suse.com
- Properly handle upgrade from old renamed hub gem
* Sat Jan 27 2018 tampakrap@opensuse.org
- Initial package
